package cn.com.ty.zuul.common;

import java.util.*;

/**
 * @author huangyuan
 * @date 2019-11-27
 * @description 常量类
 */
public class Constants {

    /**
     * 上传图片路径
     */
    public static final List<String> UPLOAD_IMAGES_URLS = Arrays.asList(
            "/files/oss",
            "/api/sensitiveWordss/inputExcel",
            "/api/alipayNotify",
            "/api/wxpayNotify",
            "/common/upload",
            "/common/uploads",
            "/scan/.*",
            "/login/getOpenId"
    );

    /**
     *  websocket请求路径
     */
    public static final List<String> WEBSOCKET_URL = Collections.singletonList(
            "/myMessageHandler"
    );

    /**
     * 公共的忽略接口
     */
    public static final List<String> COMMON_IGNORE_URLS = Arrays.asList(
            "/login/register",//注册路径
            "/login/login",//登录路径
            "/login/wxRegister",//微信注册
            "/login/wxLogin",//微信登录
            "/login/getImagCode",//获取图片验证码
            "/login/checkImagCode",//校验图片验证码
            "/login/checkMobile",//校验手机号
            "/login/smsCode",//获取短信验证码
            "/login/checkSmsCode",//校验短信验证码
            "/login/appletLogin",//小程序的登录
            "/login/bindMobile",//绑定手机号
            "/login/resetPassword"
    );

    /**
     * 不需要权限的路径
     */
    public static final List<String> COMMON_IGNORE_PERMISSION_URLS = Arrays.asList(
            "/login/resetPassword",//重置密码
            "/login/changeTeam"//切换团队
    );

    /**
     * 请求端类型 -> 请求路径集合
     */
    public static final Map<Integer, List<String>> MOBILE_TYPE_TO_IGNORE_URLS = new HashMap<>();

    /**
     * PC端通用接口，不需要权限验证
     */
    public static final List<String> PC_IGNORE_URLS = Arrays.asList(
    );

    /**
     * app端需要忽略的接口
     */
    public static final List<String> APP_IGNORE_URLS = Arrays.asList(
            "/.*"
    );

    /**
     * 小程序端需要忽略的接口
     */
    public static final List<String> APPLETS_IGNORE_URLS = Arrays.asList(
            "/.*"
    );

    /**
     * 公众号端要忽略的接口
     */
    public static final List<String> THE_PUBLIC_IGNORE_URLS = Arrays.asList(
            "/.*"
    );

    /*
     *初始化访问端的忽略路径
     */
    static {
        MOBILE_TYPE_TO_IGNORE_URLS.put(AccessType.PC_ACCESS, PC_IGNORE_URLS);
        MOBILE_TYPE_TO_IGNORE_URLS.put(AccessType.APP_ACCESS, APP_IGNORE_URLS);
        MOBILE_TYPE_TO_IGNORE_URLS.put(AccessType.APPLETS_ACCESS, APPLETS_IGNORE_URLS);
        MOBILE_TYPE_TO_IGNORE_URLS.put(AccessType.THE_PUBLIC_ACCESS, THE_PUBLIC_IGNORE_URLS);
    }

    /**
     * 当前用户id字段
     */
    public static final String CURRENT_USER_ID = "currentUserId";

    /**
     * 当前公司id
     */
    public static final String CURRENT_COMPANY_ID = "currentCompanyId";

    /**
     * 当前角色id
     */
    public static final String CURRENT_ROLE_ID = "currentRoleId";

    /**
     * 当前角色编码
     */
    public static final String CURRENT_ROLE_CODE = "currentRoleCode";

    /**
     * 当前权限路径
     */
    public static final String CURRENT_PERMISSION_URL = "currentPermissionUrl";

    /**
     * 当前用户类型
     */
    public static final String CURRENT_USER_TYPE = "currentUserType";

    /**
     * 当前用户token
     */
    public static final String CURRENT_USER_TOKEN = "token";

    /**
     * 请求参数中封装的参数
     */
    public interface FieldConstants {
        /**
         * 当前登录用户id-字段
         */
        String USER_ID_FIELD = "userId";
        /**
         * 当前公司id-字段
         */
        String MT_COMPANY_ID = "mtCompanyId";
        /**
         * 当前公司id-字段
         */
        String COMPANY_ID = "companyId";

        /**
         * 请求端类型
         */
        String MOBILE_TYPE = "mobileType";

        /**
         * 待办角色编码
         */
        String CURRENT_ROLE_CODE = "currentRoleCode";
    }

    /**
     * 状态码
     */
    public interface StatusCode {
        String RESULT_ERROR = "0";//失败
        String RESULT_NO_LOGIN = "10";//未登录
        String RESULT_NO_ACCESS = "20";//权限不足
        String RESULT_ILLEGAL_REQUEST = "30";//非法请求
    }

    /**
     * 返回类型设置
     */
    public interface ContentType {

        String JSON = "application/json;charset=utf-8";//json类型

    }

    public interface UserType {
        /**
         * 超级管理员/平台管理员
         */
        int TYPE_SUPER_ADMIN = 0;

        /**
         * 平台管理员
         */
        int TYPE_PLATFORM_ADMIN = 1;

        /**
         * 企业管理员
         */
        int TYPE_ENTERPRISE_ADMIN = 2;

    }

    /**
     * 访问端类型
     */
    public interface AccessType {
        /**
         * 访问类型字段
         */
        String ACCESS_TYPE_FIELD = "MobileType";
        /**
         * 用户验证token字段
         */
        String USER_INFO_TOKEN = "Authorization";
        /**
         * pc端访问类型
         */
        int PC_ACCESS = 0;
        /**
         * app端访问
         */
        int APP_ACCESS = 1;
        /**
         * 公众号端访问
         */
        int THE_PUBLIC_ACCESS = 2;
        /**
         * 小程序端访问
         */
        int APPLETS_ACCESS = 3;
    }

    /**
     * 设置用户id需要忽略的路径
     */

    public static final List<String> USER_ID_IGNORE_URLS = Arrays.asList(
            "/user/add",
            "/user/update",
            "/user/delete",
            "/user/changePassword",
            "/project/user/modify",
            "/project/list",
            "/capital/repair/signIn/record",
            "/region/add",
            "/region/update",
            "/oa/attendance/export",
            "/property/cancelPermission",
            "/scan/.*",
            "/api/.*"
    );
    /**
     * 设置公司id需要忽略的路径
     */
    public static final List<String> COMPANY_ID_IGNORE_URLS = Arrays.asList(
            "/menu/all",
            "/login/changeTeam",
            "/userapply/applyTeam",
            "/userapply/applyProject",
            "/mtcompany/teamInfo",
            "/oa/attendance/export",
            "/menu/companyMenu",
            "/api/.*"
    );

}
