package cn.com.ty.zuul.security.utils;

import cn.com.ty.zuul.common.Constants;
import org.apache.commons.lang3.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * @author huangyuan
 * @date 2019-11-29
 * @description 检验工具类
 */
public class VerifyUtils {

    /**
     * @param requestPath 请求路径
     * @param userInfoMap 用户信息map
     * @param mobileType  访问端类型
     * @return boolean false 表示无权限 true 表示有权限
     * @description 校验用户是否有权限
     * @date 2020-01-16 17:02
     */
    public static boolean verifyUserHasPermission(String requestPath, Map<String, Object> userInfoMap, int mobileType) {
        if (Constants.COMMON_IGNORE_PERMISSION_URLS.stream().anyMatch(requestPath::matches)) {
            return true;
        }
        //判断用户类型,超级管理员和平台管理员拥有所有权限
        Integer userType = (Integer) userInfoMap.get(Constants.CURRENT_USER_TYPE);
        if (userType == Constants.UserType.TYPE_SUPER_ADMIN ||
                userType == Constants.UserType.TYPE_PLATFORM_ADMIN) {
            return true;
        }
        //通过访问端类型获取访问端的忽略地址
        List<String> accessIgnoreUrls = Constants.MOBILE_TYPE_TO_IGNORE_URLS.get(mobileType);
        if (accessIgnoreUrls != null && accessIgnoreUrls.size() > 0) {
            //属于忽略路径就直接返回
            if (accessIgnoreUrls.stream().anyMatch(requestPath::matches)) {
                return true;
            }
        }
        String currentPermissionUrl = (String) userInfoMap.get(Constants.CURRENT_PERMISSION_URL);
        //判断路径是否有访问权限
        if (StringUtils.isNotBlank(currentPermissionUrl)) {
            return currentPermissionUrl.contains(requestPath);
        }
        return false;
    }

    /**
     * @param request 请求体
     * @return string 请求路径
     * @description
     * @date 2020/1/17 8:57 上午
     */
    public static String getRequestPath(HttpServletRequest request) {
        //获取请求路径
        String contentPath = request.getContextPath();
        String requestPath = request.getRequestURI().replace(contentPath, "");
        requestPath = requestPath.substring(requestPath.indexOf("/", 1));
        return requestPath;
    }


}
